OC.L10N.register(
    "core",
    {
    "Please select a file." : "Por favor, selecione um ficheiro.",
    "File is too big" : "O ficheiro é demasiado grande",
    "Invalid file provided" : "Ficheiro indicado inválido",
    "No image or file provided" : "Não foi indicado nenhum ficheiro ou imagem",
    "Unknown filetype" : "Tipo de ficheiro desconhecido",
    "Invalid image" : "Imagem inválida",
    "An error occurred. Please contact your admin." : "Ocorreu um erro. Por favor, contacte o seu administrador.",
    "No temporary profile picture available, try again" : "Nenhuma imagem de perfil temporária disponível, tente novamente",
    "No crop data provided" : "Não foram fornecidos dados de recorte",
    "No valid crop data provided" : "Não foram indicados dados de recorte válidos",
    "Crop is not square" : "O recorte não é quadrado",
    "Couldn't reset password because the token is invalid" : "Não foi possível repor a palavra-passe porque a senha é inválida",
    "Couldn't reset password because the token is expired" : "Não foi possível repor a palavra-passe porque a senha expirou",
    "%s password changed successfully" : "Palavra-passe de %s alterada com sucesso",
    "%s password reset" : "%s reposição da palavra-passe",
    "Couldn't send reset email. Please contact your administrator." : "Não foi possível enviar a mensagem de reposição. Por favor, contacte o seu administrador.",
    "Couldn't send mail to following users: %s " : "Não foi possível enviar a mensagem para os seguintes utilizadores: %s",
    "Preparing update" : "A preparar atualização",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair warning: " : "Aviso de correção:",
    "Repair error: " : "Erro de correção:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Por favor, utilize o atualizador de linha de comando porque a atualização automática está desativada em config.php.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: a verificar a tabela %s",
    "Turned on maintenance mode" : "Ativado o modo de manutenção",
    "Turned off maintenance mode" : "Desativado o modo de manutenção",
    "Maintenance mode is kept active" : "O modo de manutenção é mantido ativo",
    "Updating database schema" : "A atualizar o esquema da base de dados",
    "Updated database" : "Base de dados atualizada",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "A verificar se o esquema da base de dados pode ser atualizado (isto pode demorar algum tempo dependendo do tamanho da base de dados)",
    "Checked database schema update" : "Atualização do esquema da base de dados verificada.",
    "Checking updates of apps" : "A procurar por atualizações das aplicações",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "A verificar se o esquema da base de dados para %s pode ser atualizado (isto pode demorar algum tempo dependendo do tamanho da base de dados)",
    "Checked database schema update for apps" : "Atualização do esquema da base de dados para as aplicações verificada.",
    "Updated \"%s\" to %s" : "Atualizado \"%s\" para %s",
    "Set log level to debug" : "Definir nível de registo para depurar",
    "Reset log level" : "Reiniciar nível de registo",
    "Starting code integrity check" : "A iniciar a verificação da integridade do código",
    "Finished code integrity check" : "Terminada a verificação da integridade do código",
    "%s (3rdparty)" : "%s (terceiros)",
    "%s (incompatible)" : "%s (incompatível)",
    "Following apps have been disabled: %s" : "Foram desativadas as seguintes aplicações: %s",
    "Already up to date" : "Já está atualizado",
    "Sunday" : "Domingo",
    "Monday" : "Segunda",
    "Tuesday" : "Terça",
    "Wednesday" : "Quarta",
    "Thursday" : "Quinta",
    "Friday" : "Sexta",
    "Saturday" : "Sábado",
    "Sun." : "Dom.",
    "Mon." : "Seg.",
    "Tue." : "Ter.",
    "Wed." : "Qua.",
    "Thu." : "Qui.",
    "Fri." : "Sex.",
    "Sat." : "Sáb.",
    "Su" : "Dom",
    "Mo" : "Seg",
    "Tu" : "Ter",
    "We" : "Qua",
    "Th" : "Qui",
    "Fr" : "Sex",
    "Sa" : "Sáb",
    "January" : "Janeiro",
    "February" : "Fevereiro",
    "March" : "Março",
    "April" : "Abril",
    "May" : "Maio",
    "June" : "Junho",
    "July" : "Julho",
    "August" : "Agosto",
    "September" : "Setembro",
    "October" : "Outubro",
    "November" : "Novembro",
    "December" : "Dezembro",
    "Jan." : "Jan.",
    "Feb." : "Fev.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "Mai.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Ago.",
    "Sep." : "Set.",
    "Oct." : "Out.",
    "Nov." : "Nov.",
    "Dec." : "Dez.",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Existiram alguns problemas com a verificação de integridade do código. Mais informação…</a>",
    "Settings" : "Configurações",
    "Problem loading page, reloading in 5 seconds" : "Problema a carregar a página, a recarregar em 5 segundos",
    "Saving..." : "A guardar...",
    "Dismiss" : "Rejeitar",
    "seconds ago" : "segundos atrás",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "A hiperligação para reiniciar a sua senha foi enviada para o seu correio eletrónico. Se não a receber dentro de um tempo aceitável, verifique as suas pastas de span/lixo.<br> Se não a encontrar, pergunte ao seu administrador local.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Os seus ficheiros estão encriptados. Se não ativou a chave de recuperação, não terá nenhum modo para voltar obter os seus dados depois de reiniciar a sua senha. <br />Se não tem a certeza do que fazer, por favor, contacte o seu administrador antes de continuar.<br />  Tem a certeza que quer continuar?",
    "I know what I'm doing" : "Eu sei o que eu estou a fazer",
    "Password can not be changed. Please contact your administrator." : "A palavra-passe não pode ser alterada. Por favor, contacte o seu administrador.",
    "No" : "Não",
    "Yes" : "Sim",
    "Choose" : "Escolher",
    "Error loading file picker template: {error}" : "Ocorreu um erro ao carregar o modelo de seleção de ficheiro: {error}",
    "Ok" : "CONFIRMAR",
    "Error loading message template: {error}" : "Ocorreu um erro ao carregar o modelo: {error}",
    "read-only" : "só de leitura",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflito de ficheiro","{count} conflitos de ficheiro"],
    "One file conflict" : "Um conflito de ficheiro",
    "New Files" : "Novos Ficheiros",
    "Already existing files" : "Ficheiros já existentes",
    "Which files do you want to keep?" : "Quais os ficheiros que pretende manter?",
    "If you select both versions, the copied file will have a number added to its name." : "Se selecionar ambas as versões, o ficheiro copiado irá ter um número adicionado ao seu nome.",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "(all selected)" : "(todos os selecionados)",
    "({count} selected)" : "({count} selecionados)",
    "Error loading file exists template" : "Ocorreu um erro ao carregar o ficheiro do modelo existente",
    "Very weak password" : "Palavra-passe muito fraca",
    "Weak password" : "Palavra-passe fraca",
    "So-so password" : "Palavra-passe aceitável",
    "Good password" : "Palavra-passe boa",
    "Strong password" : "Palavra-passe forte",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "O seu servidor da Web não está configurado corretamente para permitir a sincronização de ficheiro, porque a interface WebDAV parece estar com problemas.",
    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "O seu servidor web não está configurado corretamente para resolver \"{url}\". Mais informação pode ser encontrada na nossa <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentação</a>.",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Este servidor ownCloud não tem uma ligação de Internet a funcionar. Isto significa que algumas funcionalidades como o acesso a locais externos, notificações sobre actualizações, ou a instalação de aplicações de terceiros não irá funcionar. Aceder aos ficheiros remotamente e enviar notificações de email poderão não funcionar também. Sugerimos que active uma ligação à Internet se pretende obter todas as funcionalidades do ownCloud.",
    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Nenhuma memória cache foi configurada. Para melhorar o seu desempenho, por favor configure a memcache, se disponível. Mais informação pode ser encontrada na nossa <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>.",
    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "/dev/urandom não é legível pelo PHP, o que é altamente desencorajado por motivos de segurança. Pode ser encontrada mais informação na <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentação</a>.",
    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Neste momento está a executar PHP {version}. Aconselhamos actualizar a versão de PHP para tirar partido das <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">actualizações de desempenho e segurança fornecidas pelo PHP Group</a> assim que a sua distribuição as suporte.",
    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "A configuração dos headers do proxy reverso está incorreta, ou então está a aceder ao ownCloud através de um proxy de confiança. Se não está a aceder ao ownCloud através de um proxy de confiança, isto é um problema de segurança e poderá permitir a um invasor falsificar um endereço IP como visível para o ownCloud. Mais informação pode ser encontrada na nossa <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentação</a>.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached está configurada como cache distribuída, mas o módulo \"memcache\" PHP errado está instalado. \\OC\\Memcache\\Memcached apenas suporta \"memcached\" e não \"memcache\". Leia a <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki sobre ambos os módulos</a>.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Alguns ficheiros não passaram na verificação de integridade. Mais informação sobre este assunto pode ser encontrada na nossa <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentação</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Lista de ficheiros inválidos…</a> / <a href=\"{rescanEndpoint}\">Reverificar…</a>)",
    "Error occurred while checking server setup" : "Ocorreu um erro durante a verificação da configuração do servidor",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "A sua pasta com os dados e os seus ficheiros estão provavelmente acessíveis a partir da Internet. O ficheiro .htaccess não está a funcionar correctamente. Sugerimos veementemente que configure o seu servidor web de maneira a que a pasta com os dados deixe de ficar acessível, ou mova a pasta com os dados para fora da raiz de documentos do servidor web.",
    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "O cabeçalho HTTP \"{header}\" não está configurado para igualar \"{expected}\". Isto é um potencial risco de segurança ou privacidade e recomendamos que o corrija.",
    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "O cabeçalho HTTP \"Strict-Transport-Security\" não está configurado para um mínimo de \"{seconds}\" segundos. Para uma segurança melhorada recomendados a ativação do HSTS como descrito nas nossas <a href=\"{docUrl}\" rel=\"noreferrer\">dicas de segurança</a>.",
    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Está a aceder a este site via HTTP. Nós recomendamos vivamente que configure o seu servidor para requerer a utilização de HTTPS,  em vez do que está descrito nas nossas <a href=\"{docUrl}\">dicas de segurança</a>.",
    "Shared" : "Partilhado",
    "Shared with {recipients}" : "Partilhado com {recipients}",
    "Error" : "Erro",
    "Error while sharing" : "Erro ao partilhar",
    "Error while unsharing" : "Erro ao remover a partilha",
    "The public link will expire no later than {days} days after it is created" : "A hiperligação pública irá expirar, o mais tardar {days} dias depois da sua criação",
    "Set expiration date" : "Definir a data de expiração",
    "Expiration" : "Expiração",
    "Expiration date" : "Data de expiração",
    "Expiration date is required" : "A data de expiração é necessária",
    "Delete {link}" : "Apagar {link}",
    "Remove link" : "Remover hiperligação",
    "{fileName} link" : "Hiperligação de {fileName}",
    "Link" : "Hiperligação",
    "Create public link" : "Criar ligação pública",
    "Edit" : "Editar",
    "Remove" : "Remover",
    "Click to copy to clipboard" : "Clique para copiar para a área de transferência",
    "Social share" : "Partilha social",
    "There are currently no link shares, you can create one" : "Atualmente não existem partilhas por hiperligação, porém, pode criar uma",
    "Anyone with the link has access to the file/folder" : "Qualquer pessoa com a hiperligação terá acesso ao ficheiro/pasta",
    "Copied!" : "Copiado!",
    "Not supported!" : "Não suportado!",
    "Press ⌘-C to copy." : "Pressione ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Pressione Ctrl-C para copiar.",
    "Choose a password for the public link" : "Defina a palavra-passe para a hiperligação pública",
    "Password required" : "Palavra-passe necessária",
    "Filename" : "Nome do ficheiro",
    "Password" : "Palavra-passe",
    "Name" : "Nome",
    "Allow editing" : "Permitir edição",
    "Show file listing" : "Mostrar listagem de ficheiros",
    "Edit link share: {name}" : "Editar partilha por hiperligação: {name}",
    "Save" : "Guardar",
    "Create link share: {name}" : "Criar partilha por hiperligação: {name}",
    "Remove password" : "Remover palavra-passe",
    "Share to Twitter. Opens in a new window." : "Partilhar no Twitter. Abre uma janela nova.",
    "Share to Facebook. Opens in a new window." : "Partilhar no Facebook. Abre uma janela nova.",
    "Share to Diaspora. Opens in a new window." : "Partilhar no Diaspora. Abre uma janela nova.",
    "Share to Google+. Opens in a new window." : "Partilhar no Google+. Abre uma janela nova.",
    "Share via email. Opens your mail client." : "Partilhar através de e-mail. Abre o seu cliente de e-mail.",
    "Error while sending notification" : "Erro enquanto estava a enviar a notificação",
    "Sending ..." : "A enviar...",
    "Email sent" : "Mensagem enviada",
    "Email link to person" : "Enviar hiperligação por mensagem para a pessoa",
    "Send link via email" : "Enviar hiperligação por mensagem",
    "Shared with you and the group {group} by {owner}" : "Partilhado consigo e com o grupo {group} por {owner}",
    "Shared with you by {owner}" : "Partilhado consigo por {owner}",
    "group" : "grupo",
    "remote" : "remoto",
    "notify by email" : "Notificar por mensagem",
    "Unshare" : "Cancelar partilha",
    "can share" : "pode partilhar",
    "can edit" : "pode editar",
    "create" : "criar",
    "change" : "alterar",
    "delete" : "eliminar",
    "access control" : "controlo de acesso",
    "Could not unshare" : "Não foi possível cancelar a partilha",
    "Share details could not be loaded for this item." : "Não foi possível carregar os detalhes de partilha para este item.",
    "No users or groups found for {search}" : "Não foram encontrados nenhuns utilizadores ou grupos para {search}",
    "No users found for {search}" : "Não foram encontrados utilizadores para {search}",
    "An error occurred. Please try again" : "Ocorreu um erro. Por favor, tente de novo.",
    "{sharee} (group)" : "{sharee} (grupo)",
    "{sharee} (at {server})" : "{sharee} (em {server})",
    "{sharee} (remote)" : "{sharee} (remoto)",
    "Share" : "Compartilhar",
    "User and Groups" : "Utilizador e Grupos",
    "Public Links" : "Ligações públicas",
    "Resharing is not allowed" : "Não é permitido voltar a partilhar",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Compartilhe com as pessoas nas outras ownClouds utilizando a sintaxe username@example.com/owncloud",
    "Share with users…" : "Compartilhe com os utilizadores...",
    "Share with users, groups or remote users…" : "Compartilhe com os utilizadores, grupos ou utilizadores remotos...",
    "Share with users or groups…" : "Compartilhe com os utilizadores ou grupos...",
    "Share with users or remote users…" : "Compartilhe com os utilizadores ou utilizadores remotos...",
    "Error removing share" : "Erro ao remover partilha",
    "Warning" : "Aviso",
    "Non-existing tag #{tag}" : "Etiqueta não existente #{tag}",
    "restricted" : "limitado",
    "invisible" : "invisível",
    "({scope})" : "({scope})",
    "Delete" : "Eliminar",
    "Rename" : "Renomear",
    "Collaborative tags" : "Etiquetas colaborativas",
    "The object type is not specified." : "O tipo de objeto não está especificado.",
    "Enter new" : "Inserir novo",
    "Add" : "Adicionar",
    "Edit tags" : "Editar etiquetas",
    "Error loading dialog template: {error}" : "Ocorreu um erro ao carregar o modelo de janela: {error}",
    "No tags selected for deletion." : "Não foram selecionadas etiquetas para eliminação.",
    "unknown text" : "texto desconhecido",
    "Hello world!" : "Olá, mundo!",
    "sunny" : "soalheiro",
    "Hello {name}, the weather is {weather}" : "Olá {name}, o tempo está {weather}",
    "Hello {name}" : "Olá {name}",
    "new" : "novo",
    "_download %n file_::_download %n files_" : ["transferir %n ficheiro","transferir %n ficheiros"],
    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "A atualização está em curso. Se deixar esta página agora poderá interromper o processo em alguns ambientes.",
    "Updating to {version}" : "A atualizar para {version}",
    "An error occurred." : "Ocorreu um erro.",
    "Please reload the page." : "Por favor, recarregue a página.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "A atualização falhou. Para mais informação <a href=\"{url}\">verifique o nosso fórum</a> sobre como resolver este problema.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "A actualização falhou. Por favor reporte este incidente seguindo este link <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>.",
    "The update was successful. There were warnings." : "A atualização foi bem sucedida. Tem alguns avisos.",
    "The update was successful. Redirecting you to ownCloud now." : "A atualização foi bem sucedida. A redirecioná-lo agora para o ownCloud.",
    "Searching other places" : "A procurar noutros lugares",
    "No search results in other folders" : "Sem resultados de procura nas outras pastas",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} resultado de procura noutra pasta","{count} resultados de procura noutras pastas"],
    "Personal" : "Pessoal",
    "Users" : "Utilizadores",
    "Apps" : "Aplicações",
    "Admin" : "Administração",
    "Help" : "Ajuda",
    "Access forbidden" : "Acesso proibido",
    "File not found" : "Ficheiro não encontrado",
    "The specified document has not been found on the server." : "O documento especificado não foi encontrado no servidor.",
    "You can click here to return to %s." : "Pode clicar aqui para voltar para %s.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Olá,\n\napenas para o informar que %s partilhou %s consigo.\nVer aqui: %s\n",
    "The share will expire on %s." : "Esta partilha irá expirar em %s.",
    "Cheers!" : "Parabéns!",
    "Internal Server Error" : "Erro Interno do Servidor",
    "The server encountered an internal error and was unable to complete your request." : "O servidor encontrou um erro interno e não conseguiu concluir o seu pedido.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Entra em contacto com o administrador do servidor se este erro aparecer várias vezes, inclui também os detalhes técnicos abaixo no seu contacto.",
    "More details can be found in the server log." : "Mais detalhes podem ser encontrados no log do servidor.",
    "Technical details" : "Detalhes técnicos",
    "Remote Address: %s" : "Endereço remoto: %s",
    "Request ID: %s" : "Id. do pedido: %s",
    "Type: %s" : "Tipo: %s",
    "Code: %s" : "Código: %s",
    "Message: %s" : "Mensagem: %s",
    "File: %s" : "Ficheiro: %s",
    "Line: %s" : "Linha: %s",
    "Trace" : "Rasto",
    "Create an <strong>admin account</strong>" : "Criar uma <strong>conta de administrador</strong>",
    "Username" : "Nome de utilizador",
    "Storage & database" : "Armazenamento e base de dados",
    "Data folder" : "Pasta de dados",
    "Configure the database" : "Configure a base de dados",
    "Only %s is available." : "Só está disponível %s.",
    "Install and activate additional PHP modules to choose other database types." : "Instale e active módulos PHP adicionais para escolher outros tipos de base de dados.",
    "For more details check out the documentation." : "Para mais detalhes consulte a documentação.",
    "Database user" : "Utilizador da base de dados",
    "Database password" : "Palavra-passe da base de dados",
    "Database name" : "Nome da base de dados",
    "Database tablespace" : "Tablespace da base de dados",
    "Database host" : "Anfitrião da base de dados",
    "Please specify the port number along with the host name (e.g., localhost: 5432)." : "Por favor, especifique o número da porta com o nome do anfitrião (exemplo, localhost: 5432).",
    "Performance warning" : "Aviso de Desempenho",
    "SQLite will be used as database." : "SQLite será utilizado como base de dados.",
    "For larger installations we recommend to choose a different database backend." : "Para instalações maiores, nós recomendamos que escolha uma interface de base de dados diferente.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "O uso de SQLite é desencorajado especialmente se estiver a pensar em dar uso ao cliente desktop para sincronizar os seus ficheiros no seu computador.",
    "Finish setup" : "Terminar consiguração",
    "Finishing …" : "A terminar...",
    "Need help?" : "Precisa de ajuda?",
    "See the documentation" : "Consulte a documentação",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Olá,<br><br>apenas para informar que %s partilhou <strong>%s</strong> consigo.<br><a href=\"%s\">Consulte aqui!</a><br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicação requer o JavaScript para funcionar corretamente. Por favor, {linkstart}ative o JavaScript{linkend} e recarregue a página.",
    "Log out" : "Terminar sessão",
    "Search" : "Procurar",
    "Server side authentication failed!" : "Autenticação do lado do servidor falhou!",
    "Please contact your administrator." : "Por favor, contacte o seu administrador.",
    "An internal error occurred." : "Ocorreu um erro interno.",
    "Please try again or contact your administrator." : "Por favor, tente de novo ou contacte o seu administrador.",
    "Username or email" : "Nome de utilizador ou e-mail",
    "Log in" : "Iniciar Sessão",
    "Wrong password. Reset it?" : "Palavra-passe errada. Redefini-la?",
    "Wrong password." : "Palavra-passe errada.",
    "Stay logged in" : "Manter sessão iniciada",
    "Alternative Logins" : "Contas de Acesso Alternativas",
    "Use the following link to reset your password: {link}" : "Utilize a seguinte hiperligação para repor a sua palavra-passe: {link}",
    "Password changed successfully" : "Palavra-passe alterada com sucesso",
    "New password" : "Nova palavra-passe",
    "New Password" : "Nova palavra-passe",
    "Reset password" : "Repor palavra-passe",
    "This ownCloud instance is currently in single user mode." : "Esta instância do ownCloud está atualmente configurada no modo de único utilizador.",
    "This means only administrators can use the instance." : "Isto significa que apenas os administradores podem utilizar a instância.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte o seu administrador do sistema se esta mensagem persistir ou apareceu inesperadamente.",
    "Thank you for your patience." : "Obrigado pela sua paciência.",
    "Two-step verification" : "Verificação de dois passos:",
    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "A segurança reforçada foi ativada para a sua conta. Por favor, autentique utilizando um segundo fator.",
    "Cancel login" : "Cancelar entrada",
    "Please authenticate using the selected factor." : "Por favor, autentique utilizando um segundo fator.",
    "An error occurred while verifying the token" : "Ocorreu um erro durante a verificação do código",
    "You are accessing the server from an untrusted domain." : "Está a aceder ao servidor a partir de um domínio que não é de confiança.",
    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Por favor, contacte o seu administrador. Se é um administrador desta instância, configure a definição \"trusted_domains\" em config/config.php. É fornecido um exemplo de configuração em config/config.sample.php.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Dependendo da sua configuração, como um administrador também pode conseguir utilizar o botão abaixo para confiar neste domínio.",
    "Add \"%s\" as trusted domain" : "Adicionar \"%s\" como um domínio de confiança",
    "App update required" : "É necessário atualizar a aplicação",
    "%s will be updated to version %s" : "%s será atualizada para a versão %s.",
    "These apps will be updated:" : "Estas aplicações irão ser atualizadas.",
    "The theme %s has been disabled." : "O tema %s foi desativado.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Por favor, certifique-se de que foi efetuada uma cópia de segurança da base de dados, pasta de configuração e de dados antes de prosseguir.",
    "Start update" : "Iniciar atualização",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar tempos expirados com instalações maiores, em vez disso, pode executar o seguinte comando a partir da diretoria de instalação:",
    "Detailed logs" : "Registos detalhados",
    "Update needed" : "É necessário atualizar",
    "Please use the command line updater because you have a big instance." : "Por favor, utilize o atualizador de linha de comando porque a sua instância é grande.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Para obter ajuda, consulte a <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentação</a>.",
    "This %s instance is currently in maintenance mode, which may take a while." : "Esta instância %s está atualmente no modo de manutenção, o que poderá demorar algum tempo.",
    "This page will refresh itself when the %s instance is available again." : "Esta página irá ser atualizada quando a instância %s ficar novamente disponível.",
    "Could not reset password because the token is invalid" : "Não foi possível repor a palavra-passe porque o token é inválido",
    "Copy to clipboard" : "Copiar para a área de trânsferencia",
    "Choose a password" : "Escolha uma palavra-passe",
    "Upload only" : "Apenas envio",
    "Sending" : "A Enviar",
    "Menu" : "Menu",
    "Link name" : "Nome de hiperligação",
    "Owner: {owner}" : "Proprietário: {owner}",
    "Imprint" : "Marca",
    "Could not reset password because the token expired" : "Não foi possível redefinir a palavra-passe porque o código expirou",
    "Could not reset password because the token does not match" : "Não foi possível redefinir a palavra-passe porque o código não corresponde",
    "Privacy Policy" : "Política de Privacidade"
},
"nplurals=2; plural=(n != 1);");
